shortener

package module
v0.0.0-...-8ea5078 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 13, 2022 License: MIT Imports: 4 Imported by: 0

README

shortener

The shortener package creates unique short url.

Go Reference Go Report Card

Install

go get github.com/semkihosh/shortener

Task

Create your own package (url shortener, any other idea) following best practices with examples of function usage and nice godoc page. Evaluation requirements will be defined by the mentor. Evaluation criteria:

  • Mentee should provide a link to the repository with the source code
  • Package should be go gettable
  • Package should contain comments for exportable functions
  • Package should be readable by https://pkg.go.dev/

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ShortURL

func ShortURL(base string) (string, error)

ShortURL creates short unique URL for the given base. If provided base is not invalid, it returns error.

func UniqueCode

func UniqueCode() string

UniqueCode generates unique short code. Safe for concurrent use.

Types

This section is empty.

Jump to